@@ -1111,13 +1111,13 @@ class TestDatasetNoncore:
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "1416RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "18/04/2001",
                             "YEAR": "2001",
                             "TIME_PRECISION": "1",
                             "EVENT_TYPE": "Violence against civilians",
                             "ACTOR1": "Police Forces of Algeria (1999-)",
-                            "ALLY_ACTOR_1": "",
+                            "ALLY_ACTOR_1": None,
                             "INTER1": "1",
                             "ACTOR2": "Civilians (Algeria)",
                             "ALLY_ACTOR_2": "Berber Ethnic Group (Algeria)",
@@ -1126,7 +1126,7 @@ class TestDatasetNoncore:
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Tizi Ouzou",
                             "ADMIN2": "Beni-Douala",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Beni Douala",
                             "LATITUDE": "36.61954",
                             "LONGITUDE": "4.08282",
@@ -1139,7 +1139,7 @@ class TestDatasetNoncore:
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "2229RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "19/04/2001",
                             "YEAR": "2001",
                             "TIME_PRECISION": "1",
@@ -1148,13 +1148,13 @@ class TestDatasetNoncore:
                             "ALLY_ACTOR_1": "Berber Ethnic Group (Algeria)",
                             "INTER1": "5",
                             "ACTOR2": "Police Forces of Algeria (1999-)",
-                            "ALLY_ACTOR_2": "",
+                            "ALLY_ACTOR_2": None,
                             "INTER2": "1",
                             "INTERACTION": "15",
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Tizi Ouzou",
                             "ADMIN2": "Tizi Ouzou",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Tizi Ouzou",
                             "LATITUDE": "36.71183",
                             "LONGITUDE": "4.04591",
@@ -1167,7 +1167,7 @@ class TestDatasetNoncore:
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "2230RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "20/04/2001",
                             "YEAR": "2002",
                             "TIME_PRECISION": "1",
@@ -1175,27 +1175,27 @@ class TestDatasetNoncore:
                             "ACTOR1": "Protesters (Algeria)",
                             "ALLY_ACTOR_1": "Students (Algeria)",
                             "INTER1": "6",
-                            "ACTOR2": "",
-                            "ALLY_ACTOR_2": "",
+                            "ACTOR2": None,
+                            "ALLY_ACTOR_2": None,
                             "INTER2": "0",
                             "INTERACTION": "60",
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Bejaia",
                             "ADMIN2": "Amizour",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Amizour",
                             "LATITUDE": "36.64022",
                             "LONGITUDE": "4.90131",
                             "GEO_PRECISION": "1",
                             "SOURCE": "Crisis Group",
                             "NOTES": "Students protested in the Amizour area. At least 3 were later arrested for allegedly insulting gendarmes.",
-                            "FATALITIES": "",
+                            "FATALITIES": None,
                             "lala": "lala",
                         },
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "2231RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "21/04/2001",
                             "YEAR": "2001",
                             "TIME_PRECISION": "1",
@@ -1204,13 +1204,13 @@ class TestDatasetNoncore:
                             "ALLY_ACTOR_1": "Berber Ethnic Group (Algeria)",
                             "INTER1": "5",
                             "ACTOR2": "Police Forces of Algeria (1999-)",
-                            "ALLY_ACTOR_2": "",
+                            "ALLY_ACTOR_2": None,
                             "INTER2": "1",
                             "INTERACTION": "15",
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Bejaia",
                             "ADMIN2": "Amizour",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Amizour",
                             "LATITUDE": "36.64022",
                             "LONGITUDE": "4.90131",
@@ -1275,7 +1275,7 @@ class TestDatasetNoncore:
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Tizi Ouzou",
                             "ADMIN2": "Beni-Douala",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Beni Douala",
                             "LATITUDE": "36.61954",
                             "LONGITUDE": "4.08282",
@@ -1293,7 +1293,7 @@ class TestDatasetNoncore:
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Bejaia",
                             "ADMIN2": "Amizour",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Amizour",
                             "LATITUDE": "36.64022",
                             "LONGITUDE": "4.90131",
@@ -1444,13 +1444,13 @@ class TestDatasetNoncore:
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "1416RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "18/04/2001",
                             "YEAR": "2001",
                             "TIME_PRECISION": "1",
                             "EVENT_TYPE": "Violence against civilians",
                             "ACTOR1": "Police Forces of Algeria (1999-)",
-                            "ALLY_ACTOR_1": "",
+                            "ALLY_ACTOR_1": None,
                             "INTER1": "1",
                             "ACTOR2": "Civilians (Algeria)",
                             "ALLY_ACTOR_2": "Berber Ethnic Group (Algeria)",
@@ -1459,7 +1459,7 @@ class TestDatasetNoncore:
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Tizi Ouzou",
                             "ADMIN2": "Beni-Douala",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Beni Douala",
                             "LATITUDE": "36.61954",
                             "LONGITUDE": "4.08282",
@@ -1472,7 +1472,7 @@ class TestDatasetNoncore:
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "2229RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "19/04/2001",
                             "YEAR": "2001",
                             "TIME_PRECISION": "1",
@@ -1481,13 +1481,13 @@ class TestDatasetNoncore:
                             "ALLY_ACTOR_1": "Berber Ethnic Group (Algeria)",
                             "INTER1": "5",
                             "ACTOR2": "Police Forces of Algeria (1999-)",
-                            "ALLY_ACTOR_2": "",
+                            "ALLY_ACTOR_2": None,
                             "INTER2": "1",
                             "INTERACTION": "15",
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Tizi Ouzou",
                             "ADMIN2": "Tizi Ouzou",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Tizi Ouzou",
                             "LATITUDE": "36.71183",
                             "LONGITUDE": "4.04591",
@@ -1500,7 +1500,7 @@ class TestDatasetNoncore:
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "2230RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "20/04/2001",
                             "YEAR": "2002",
                             "TIME_PRECISION": "1",
@@ -1508,27 +1508,27 @@ class TestDatasetNoncore:
                             "ACTOR1": "Protesters (Algeria)",
                             "ALLY_ACTOR_1": "Students (Algeria)",
                             "INTER1": "6",
-                            "ACTOR2": "",
-                            "ALLY_ACTOR_2": "",
+                            "ACTOR2": None,
+                            "ALLY_ACTOR_2": None,
                             "INTER2": "0",
                             "INTERACTION": "60",
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Bejaia",
                             "ADMIN2": "Amizour",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Amizour",
                             "LATITUDE": "36.64022",
                             "LONGITUDE": "4.90131",
                             "GEO_PRECISION": "1",
                             "SOURCE": "Crisis Group",
                             "NOTES": "Students protested in the Amizour area. At least 3 were later arrested for allegedly insulting gendarmes.",
-                            "FATALITIES": "",
+                            "FATALITIES": None,
                             "lala": "lala",
                         },
                         {
                             "GWNO": "615",
                             "EVENT_ID_CNTY": "2231RTA",
-                            "EVENT_ID_NO_CNTY": "",
+                            "EVENT_ID_NO_CNTY": None,
                             "EVENT_DATE": "21/04/2001",
                             "YEAR": "2001",
                             "TIME_PRECISION": "1",
@@ -1537,13 +1537,13 @@ class TestDatasetNoncore:
                             "ALLY_ACTOR_1": "Berber Ethnic Group (Algeria)",
                             "INTER1": "5",
                             "ACTOR2": "Police Forces of Algeria (1999-)",
-                            "ALLY_ACTOR_2": "",
+                            "ALLY_ACTOR_2": None,
                             "INTER2": "1",
                             "INTERACTION": "15",
                             "COUNTRY": "Algeria",
                             "ADMIN1": "Bejaia",
                             "ADMIN2": "Amizour",
-                            "ADMIN3": "",
+                            "ADMIN3": None,
                             "LOCATION": "Amizour",
                             "LATITUDE": "36.64022",
                             "LONGITUDE": "4.90131",
